import reflex as rx

class IoIosAddCircleOutline(rx.Component):
    library = "react-icons/io"
    tag = "IoIosAddCircleOutline"


class IoIosAddCircle(rx.Component):
    library = "react-icons/io"
    tag = "IoIosAddCircle"


class IoIosAdd(rx.Component):
    library = "react-icons/io"
    tag = "IoIosAdd"


class IoIosAirplane(rx.Component):
    library = "react-icons/io"
    tag = "IoIosAirplane"


class IoIosAlarm(rx.Component):
    library = "react-icons/io"
    tag = "IoIosAlarm"


class IoIosAlbums(rx.Component):
    library = "react-icons/io"
    tag = "IoIosAlbums"


class IoIosAlert(rx.Component):
    library = "react-icons/io"
    tag = "IoIosAlert"


class IoIosAmericanFootball(rx.Component):
    library = "react-icons/io"
    tag = "IoIosAmericanFootball"


class IoIosAnalytics(rx.Component):
    library = "react-icons/io"
    tag = "IoIosAnalytics"


class IoIosAperture(rx.Component):
    library = "react-icons/io"
    tag = "IoIosAperture"


class IoIosApps(rx.Component):
    library = "react-icons/io"
    tag = "IoIosApps"


class IoIosAppstore(rx.Component):
    library = "react-icons/io"
    tag = "IoIosAppstore"


class IoIosArchive(rx.Component):
    library = "react-icons/io"
    tag = "IoIosArchive"


class IoIosArrowBack(rx.Component):
    library = "react-icons/io"
    tag = "IoIosArrowBack"


class IoIosArrowDown(rx.Component):
    library = "react-icons/io"
    tag = "IoIosArrowDown"


class IoIosArrowDropdownCircle(rx.Component):
    library = "react-icons/io"
    tag = "IoIosArrowDropdownCircle"


class IoIosArrowDropdown(rx.Component):
    library = "react-icons/io"
    tag = "IoIosArrowDropdown"


class IoIosArrowDropleftCircle(rx.Component):
    library = "react-icons/io"
    tag = "IoIosArrowDropleftCircle"


class IoIosArrowDropleft(rx.Component):
    library = "react-icons/io"
    tag = "IoIosArrowDropleft"


class IoIosArrowDroprightCircle(rx.Component):
    library = "react-icons/io"
    tag = "IoIosArrowDroprightCircle"


class IoIosArrowDropright(rx.Component):
    library = "react-icons/io"
    tag = "IoIosArrowDropright"


class IoIosArrowDropupCircle(rx.Component):
    library = "react-icons/io"
    tag = "IoIosArrowDropupCircle"


class IoIosArrowDropup(rx.Component):
    library = "react-icons/io"
    tag = "IoIosArrowDropup"


class IoIosArrowForward(rx.Component):
    library = "react-icons/io"
    tag = "IoIosArrowForward"


class IoIosArrowRoundBack(rx.Component):
    library = "react-icons/io"
    tag = "IoIosArrowRoundBack"


class IoIosArrowRoundDown(rx.Component):
    library = "react-icons/io"
    tag = "IoIosArrowRoundDown"


class IoIosArrowRoundForward(rx.Component):
    library = "react-icons/io"
    tag = "IoIosArrowRoundForward"


class IoIosArrowRoundUp(rx.Component):
    library = "react-icons/io"
    tag = "IoIosArrowRoundUp"


class IoIosArrowUp(rx.Component):
    library = "react-icons/io"
    tag = "IoIosArrowUp"


class IoIosAt(rx.Component):
    library = "react-icons/io"
    tag = "IoIosAt"


class IoIosAttach(rx.Component):
    library = "react-icons/io"
    tag = "IoIosAttach"


class IoIosBackspace(rx.Component):
    library = "react-icons/io"
    tag = "IoIosBackspace"


class IoIosBarcode(rx.Component):
    library = "react-icons/io"
    tag = "IoIosBarcode"


class IoIosBaseball(rx.Component):
    library = "react-icons/io"
    tag = "IoIosBaseball"


class IoIosBasket(rx.Component):
    library = "react-icons/io"
    tag = "IoIosBasket"


class IoIosBasketball(rx.Component):
    library = "react-icons/io"
    tag = "IoIosBasketball"


class IoIosBatteryCharging(rx.Component):
    library = "react-icons/io"
    tag = "IoIosBatteryCharging"


class IoIosBatteryDead(rx.Component):
    library = "react-icons/io"
    tag = "IoIosBatteryDead"


class IoIosBatteryFull(rx.Component):
    library = "react-icons/io"
    tag = "IoIosBatteryFull"


class IoIosBeaker(rx.Component):
    library = "react-icons/io"
    tag = "IoIosBeaker"


class IoIosBed(rx.Component):
    library = "react-icons/io"
    tag = "IoIosBed"


class IoIosBeer(rx.Component):
    library = "react-icons/io"
    tag = "IoIosBeer"


class IoIosBicycle(rx.Component):
    library = "react-icons/io"
    tag = "IoIosBicycle"


class IoIosBluetooth(rx.Component):
    library = "react-icons/io"
    tag = "IoIosBluetooth"


class IoIosBoat(rx.Component):
    library = "react-icons/io"
    tag = "IoIosBoat"


class IoIosBody(rx.Component):
    library = "react-icons/io"
    tag = "IoIosBody"


class IoIosBonfire(rx.Component):
    library = "react-icons/io"
    tag = "IoIosBonfire"


class IoIosBook(rx.Component):
    library = "react-icons/io"
    tag = "IoIosBook"


class IoIosBookmark(rx.Component):
    library = "react-icons/io"
    tag = "IoIosBookmark"


class IoIosBookmarks(rx.Component):
    library = "react-icons/io"
    tag = "IoIosBookmarks"


class IoIosBowtie(rx.Component):
    library = "react-icons/io"
    tag = "IoIosBowtie"


class IoIosBriefcase(rx.Component):
    library = "react-icons/io"
    tag = "IoIosBriefcase"


class IoIosBrowsers(rx.Component):
    library = "react-icons/io"
    tag = "IoIosBrowsers"


class IoIosBrush(rx.Component):
    library = "react-icons/io"
    tag = "IoIosBrush"


class IoIosBug(rx.Component):
    library = "react-icons/io"
    tag = "IoIosBug"


class IoIosBuild(rx.Component):
    library = "react-icons/io"
    tag = "IoIosBuild"


class IoIosBulb(rx.Component):
    library = "react-icons/io"
    tag = "IoIosBulb"


class IoIosBus(rx.Component):
    library = "react-icons/io"
    tag = "IoIosBus"


class IoIosBusiness(rx.Component):
    library = "react-icons/io"
    tag = "IoIosBusiness"


class IoIosCafe(rx.Component):
    library = "react-icons/io"
    tag = "IoIosCafe"


class IoIosCalculator(rx.Component):
    library = "react-icons/io"
    tag = "IoIosCalculator"


class IoIosCalendar(rx.Component):
    library = "react-icons/io"
    tag = "IoIosCalendar"


class IoIosCall(rx.Component):
    library = "react-icons/io"
    tag = "IoIosCall"


class IoIosCamera(rx.Component):
    library = "react-icons/io"
    tag = "IoIosCamera"


class IoIosCar(rx.Component):
    library = "react-icons/io"
    tag = "IoIosCar"


class IoIosCard(rx.Component):
    library = "react-icons/io"
    tag = "IoIosCard"


class IoIosCart(rx.Component):
    library = "react-icons/io"
    tag = "IoIosCart"


class IoIosCash(rx.Component):
    library = "react-icons/io"
    tag = "IoIosCash"


class IoIosCellular(rx.Component):
    library = "react-icons/io"
    tag = "IoIosCellular"


class IoIosChatboxes(rx.Component):
    library = "react-icons/io"
    tag = "IoIosChatboxes"


class IoIosChatbubbles(rx.Component):
    library = "react-icons/io"
    tag = "IoIosChatbubbles"


class IoIosCheckboxOutline(rx.Component):
    library = "react-icons/io"
    tag = "IoIosCheckboxOutline"


class IoIosCheckbox(rx.Component):
    library = "react-icons/io"
    tag = "IoIosCheckbox"


class IoIosCheckmarkCircleOutline(rx.Component):
    library = "react-icons/io"
    tag = "IoIosCheckmarkCircleOutline"


class IoIosCheckmarkCircle(rx.Component):
    library = "react-icons/io"
    tag = "IoIosCheckmarkCircle"


class IoIosCheckmark(rx.Component):
    library = "react-icons/io"
    tag = "IoIosCheckmark"


class IoIosClipboard(rx.Component):
    library = "react-icons/io"
    tag = "IoIosClipboard"


class IoIosClock(rx.Component):
    library = "react-icons/io"
    tag = "IoIosClock"


class IoIosCloseCircleOutline(rx.Component):
    library = "react-icons/io"
    tag = "IoIosCloseCircleOutline"


class IoIosCloseCircle(rx.Component):
    library = "react-icons/io"
    tag = "IoIosCloseCircle"


class IoIosClose(rx.Component):
    library = "react-icons/io"
    tag = "IoIosClose"


class IoIosCloudCircle(rx.Component):
    library = "react-icons/io"
    tag = "IoIosCloudCircle"


class IoIosCloudDone(rx.Component):
    library = "react-icons/io"
    tag = "IoIosCloudDone"


class IoIosCloudDownload(rx.Component):
    library = "react-icons/io"
    tag = "IoIosCloudDownload"


class IoIosCloudOutline(rx.Component):
    library = "react-icons/io"
    tag = "IoIosCloudOutline"


class IoIosCloudUpload(rx.Component):
    library = "react-icons/io"
    tag = "IoIosCloudUpload"


class IoIosCloud(rx.Component):
    library = "react-icons/io"
    tag = "IoIosCloud"


class IoIosCloudyNight(rx.Component):
    library = "react-icons/io"
    tag = "IoIosCloudyNight"


class IoIosCloudy(rx.Component):
    library = "react-icons/io"
    tag = "IoIosCloudy"


class IoIosCodeDownload(rx.Component):
    library = "react-icons/io"
    tag = "IoIosCodeDownload"


class IoIosCodeWorking(rx.Component):
    library = "react-icons/io"
    tag = "IoIosCodeWorking"


class IoIosCode(rx.Component):
    library = "react-icons/io"
    tag = "IoIosCode"


class IoIosCog(rx.Component):
    library = "react-icons/io"
    tag = "IoIosCog"


class IoIosColorFill(rx.Component):
    library = "react-icons/io"
    tag = "IoIosColorFill"


class IoIosColorFilter(rx.Component):
    library = "react-icons/io"
    tag = "IoIosColorFilter"


class IoIosColorPalette(rx.Component):
    library = "react-icons/io"
    tag = "IoIosColorPalette"


class IoIosColorWand(rx.Component):
    library = "react-icons/io"
    tag = "IoIosColorWand"


class IoIosCompass(rx.Component):
    library = "react-icons/io"
    tag = "IoIosCompass"


class IoIosConstruct(rx.Component):
    library = "react-icons/io"
    tag = "IoIosConstruct"


class IoIosContact(rx.Component):
    library = "react-icons/io"
    tag = "IoIosContact"


class IoIosContacts(rx.Component):
    library = "react-icons/io"
    tag = "IoIosContacts"


class IoIosContract(rx.Component):
    library = "react-icons/io"
    tag = "IoIosContract"


class IoIosContrast(rx.Component):
    library = "react-icons/io"
    tag = "IoIosContrast"


class IoIosCopy(rx.Component):
    library = "react-icons/io"
    tag = "IoIosCopy"


class IoIosCreate(rx.Component):
    library = "react-icons/io"
    tag = "IoIosCreate"


class IoIosCrop(rx.Component):
    library = "react-icons/io"
    tag = "IoIosCrop"


class IoIosCube(rx.Component):
    library = "react-icons/io"
    tag = "IoIosCube"


class IoIosCut(rx.Component):
    library = "react-icons/io"
    tag = "IoIosCut"


class IoIosDesktop(rx.Component):
    library = "react-icons/io"
    tag = "IoIosDesktop"


class IoIosDisc(rx.Component):
    library = "react-icons/io"
    tag = "IoIosDisc"


class IoIosDocument(rx.Component):
    library = "react-icons/io"
    tag = "IoIosDocument"


class IoIosDoneAll(rx.Component):
    library = "react-icons/io"
    tag = "IoIosDoneAll"


class IoIosDownload(rx.Component):
    library = "react-icons/io"
    tag = "IoIosDownload"


class IoIosEasel(rx.Component):
    library = "react-icons/io"
    tag = "IoIosEasel"


class IoIosEgg(rx.Component):
    library = "react-icons/io"
    tag = "IoIosEgg"


class IoIosExit(rx.Component):
    library = "react-icons/io"
    tag = "IoIosExit"


class IoIosExpand(rx.Component):
    library = "react-icons/io"
    tag = "IoIosExpand"


class IoIosEyeOff(rx.Component):
    library = "react-icons/io"
    tag = "IoIosEyeOff"


class IoIosEye(rx.Component):
    library = "react-icons/io"
    tag = "IoIosEye"


class IoIosFastforward(rx.Component):
    library = "react-icons/io"
    tag = "IoIosFastforward"


class IoIosFemale(rx.Component):
    library = "react-icons/io"
    tag = "IoIosFemale"


class IoIosFiling(rx.Component):
    library = "react-icons/io"
    tag = "IoIosFiling"


class IoIosFilm(rx.Component):
    library = "react-icons/io"
    tag = "IoIosFilm"


class IoIosFingerPrint(rx.Component):
    library = "react-icons/io"
    tag = "IoIosFingerPrint"


class IoIosFitness(rx.Component):
    library = "react-icons/io"
    tag = "IoIosFitness"


class IoIosFlag(rx.Component):
    library = "react-icons/io"
    tag = "IoIosFlag"


class IoIosFlame(rx.Component):
    library = "react-icons/io"
    tag = "IoIosFlame"


class IoIosFlashOff(rx.Component):
    library = "react-icons/io"
    tag = "IoIosFlashOff"


class IoIosFlash(rx.Component):
    library = "react-icons/io"
    tag = "IoIosFlash"


class IoIosFlashlight(rx.Component):
    library = "react-icons/io"
    tag = "IoIosFlashlight"


class IoIosFlask(rx.Component):
    library = "react-icons/io"
    tag = "IoIosFlask"


class IoIosFlower(rx.Component):
    library = "react-icons/io"
    tag = "IoIosFlower"


class IoIosFolderOpen(rx.Component):
    library = "react-icons/io"
    tag = "IoIosFolderOpen"


class IoIosFolder(rx.Component):
    library = "react-icons/io"
    tag = "IoIosFolder"


class IoIosFootball(rx.Component):
    library = "react-icons/io"
    tag = "IoIosFootball"


class IoIosFunnel(rx.Component):
    library = "react-icons/io"
    tag = "IoIosFunnel"


class IoIosGift(rx.Component):
    library = "react-icons/io"
    tag = "IoIosGift"


class IoIosGitBranch(rx.Component):
    library = "react-icons/io"
    tag = "IoIosGitBranch"


class IoIosGitCommit(rx.Component):
    library = "react-icons/io"
    tag = "IoIosGitCommit"


class IoIosGitCompare(rx.Component):
    library = "react-icons/io"
    tag = "IoIosGitCompare"


class IoIosGitMerge(rx.Component):
    library = "react-icons/io"
    tag = "IoIosGitMerge"


class IoIosGitNetwork(rx.Component):
    library = "react-icons/io"
    tag = "IoIosGitNetwork"


class IoIosGitPullRequest(rx.Component):
    library = "react-icons/io"
    tag = "IoIosGitPullRequest"


class IoIosGlasses(rx.Component):
    library = "react-icons/io"
    tag = "IoIosGlasses"


class IoIosGlobe(rx.Component):
    library = "react-icons/io"
    tag = "IoIosGlobe"


class IoIosGrid(rx.Component):
    library = "react-icons/io"
    tag = "IoIosGrid"


class IoIosHammer(rx.Component):
    library = "react-icons/io"
    tag = "IoIosHammer"


class IoIosHand(rx.Component):
    library = "react-icons/io"
    tag = "IoIosHand"


class IoIosHappy(rx.Component):
    library = "react-icons/io"
    tag = "IoIosHappy"


class IoIosHeadset(rx.Component):
    library = "react-icons/io"
    tag = "IoIosHeadset"


class IoIosHeartDislike(rx.Component):
    library = "react-icons/io"
    tag = "IoIosHeartDislike"


class IoIosHeartEmpty(rx.Component):
    library = "react-icons/io"
    tag = "IoIosHeartEmpty"


class IoIosHeartHalf(rx.Component):
    library = "react-icons/io"
    tag = "IoIosHeartHalf"


class IoIosHeart(rx.Component):
    library = "react-icons/io"
    tag = "IoIosHeart"


class IoIosHelpBuoy(rx.Component):
    library = "react-icons/io"
    tag = "IoIosHelpBuoy"


class IoIosHelpCircleOutline(rx.Component):
    library = "react-icons/io"
    tag = "IoIosHelpCircleOutline"


class IoIosHelpCircle(rx.Component):
    library = "react-icons/io"
    tag = "IoIosHelpCircle"


class IoIosHelp(rx.Component):
    library = "react-icons/io"
    tag = "IoIosHelp"


class IoIosHome(rx.Component):
    library = "react-icons/io"
    tag = "IoIosHome"


class IoIosHourglass(rx.Component):
    library = "react-icons/io"
    tag = "IoIosHourglass"


class IoIosIceCream(rx.Component):
    library = "react-icons/io"
    tag = "IoIosIceCream"


class IoIosImage(rx.Component):
    library = "react-icons/io"
    tag = "IoIosImage"


class IoIosImages(rx.Component):
    library = "react-icons/io"
    tag = "IoIosImages"


class IoIosInfinite(rx.Component):
    library = "react-icons/io"
    tag = "IoIosInfinite"


class IoIosInformationCircleOutline(rx.Component):
    library = "react-icons/io"
    tag = "IoIosInformationCircleOutline"


class IoIosInformationCircle(rx.Component):
    library = "react-icons/io"
    tag = "IoIosInformationCircle"


class IoIosInformation(rx.Component):
    library = "react-icons/io"
    tag = "IoIosInformation"


class IoIosJet(rx.Component):
    library = "react-icons/io"
    tag = "IoIosJet"


class IoIosJournal(rx.Component):
    library = "react-icons/io"
    tag = "IoIosJournal"


class IoIosKey(rx.Component):
    library = "react-icons/io"
    tag = "IoIosKey"


class IoIosKeypad(rx.Component):
    library = "react-icons/io"
    tag = "IoIosKeypad"


class IoIosLaptop(rx.Component):
    library = "react-icons/io"
    tag = "IoIosLaptop"


class IoIosLeaf(rx.Component):
    library = "react-icons/io"
    tag = "IoIosLeaf"


class IoIosLink(rx.Component):
    library = "react-icons/io"
    tag = "IoIosLink"


class IoIosListBox(rx.Component):
    library = "react-icons/io"
    tag = "IoIosListBox"


class IoIosList(rx.Component):
    library = "react-icons/io"
    tag = "IoIosList"


class IoIosLocate(rx.Component):
    library = "react-icons/io"
    tag = "IoIosLocate"


class IoIosLock(rx.Component):
    library = "react-icons/io"
    tag = "IoIosLock"


class IoIosLogIn(rx.Component):
    library = "react-icons/io"
    tag = "IoIosLogIn"


class IoIosLogOut(rx.Component):
    library = "react-icons/io"
    tag = "IoIosLogOut"


class IoIosMagnet(rx.Component):
    library = "react-icons/io"
    tag = "IoIosMagnet"


class IoIosMailOpen(rx.Component):
    library = "react-icons/io"
    tag = "IoIosMailOpen"


class IoIosMailUnread(rx.Component):
    library = "react-icons/io"
    tag = "IoIosMailUnread"


class IoIosMail(rx.Component):
    library = "react-icons/io"
    tag = "IoIosMail"


class IoIosMale(rx.Component):
    library = "react-icons/io"
    tag = "IoIosMale"


class IoIosMan(rx.Component):
    library = "react-icons/io"
    tag = "IoIosMan"


class IoIosMap(rx.Component):
    library = "react-icons/io"
    tag = "IoIosMap"


class IoIosMedal(rx.Component):
    library = "react-icons/io"
    tag = "IoIosMedal"


class IoIosMedical(rx.Component):
    library = "react-icons/io"
    tag = "IoIosMedical"


class IoIosMedkit(rx.Component):
    library = "react-icons/io"
    tag = "IoIosMedkit"


class IoIosMegaphone(rx.Component):
    library = "react-icons/io"
    tag = "IoIosMegaphone"


class IoIosMenu(rx.Component):
    library = "react-icons/io"
    tag = "IoIosMenu"


class IoIosMicOff(rx.Component):
    library = "react-icons/io"
    tag = "IoIosMicOff"


class IoIosMic(rx.Component):
    library = "react-icons/io"
    tag = "IoIosMic"


class IoIosMicrophone(rx.Component):
    library = "react-icons/io"
    tag = "IoIosMicrophone"


class IoIosMoon(rx.Component):
    library = "react-icons/io"
    tag = "IoIosMoon"


class IoIosMore(rx.Component):
    library = "react-icons/io"
    tag = "IoIosMore"


class IoIosMove(rx.Component):
    library = "react-icons/io"
    tag = "IoIosMove"


class IoIosMusicalNote(rx.Component):
    library = "react-icons/io"
    tag = "IoIosMusicalNote"


class IoIosMusicalNotes(rx.Component):
    library = "react-icons/io"
    tag = "IoIosMusicalNotes"


class IoIosNavigate(rx.Component):
    library = "react-icons/io"
    tag = "IoIosNavigate"


class IoIosNotificationsOff(rx.Component):
    library = "react-icons/io"
    tag = "IoIosNotificationsOff"


class IoIosNotificationsOutline(rx.Component):
    library = "react-icons/io"
    tag = "IoIosNotificationsOutline"


class IoIosNotifications(rx.Component):
    library = "react-icons/io"
    tag = "IoIosNotifications"


class IoIosNuclear(rx.Component):
    library = "react-icons/io"
    tag = "IoIosNuclear"


class IoIosNutrition(rx.Component):
    library = "react-icons/io"
    tag = "IoIosNutrition"


class IoIosOpen(rx.Component):
    library = "react-icons/io"
    tag = "IoIosOpen"


class IoIosOptions(rx.Component):
    library = "react-icons/io"
    tag = "IoIosOptions"


class IoIosOutlet(rx.Component):
    library = "react-icons/io"
    tag = "IoIosOutlet"


class IoIosPaperPlane(rx.Component):
    library = "react-icons/io"
    tag = "IoIosPaperPlane"


class IoIosPaper(rx.Component):
    library = "react-icons/io"
    tag = "IoIosPaper"


class IoIosPartlySunny(rx.Component):
    library = "react-icons/io"
    tag = "IoIosPartlySunny"


class IoIosPause(rx.Component):
    library = "react-icons/io"
    tag = "IoIosPause"


class IoIosPaw(rx.Component):
    library = "react-icons/io"
    tag = "IoIosPaw"


class IoIosPeople(rx.Component):
    library = "react-icons/io"
    tag = "IoIosPeople"


class IoIosPersonAdd(rx.Component):
    library = "react-icons/io"
    tag = "IoIosPersonAdd"


class IoIosPerson(rx.Component):
    library = "react-icons/io"
    tag = "IoIosPerson"


class IoIosPhoneLandscape(rx.Component):
    library = "react-icons/io"
    tag = "IoIosPhoneLandscape"


class IoIosPhonePortrait(rx.Component):
    library = "react-icons/io"
    tag = "IoIosPhonePortrait"


class IoIosPhotos(rx.Component):
    library = "react-icons/io"
    tag = "IoIosPhotos"


class IoIosPie(rx.Component):
    library = "react-icons/io"
    tag = "IoIosPie"


class IoIosPin(rx.Component):
    library = "react-icons/io"
    tag = "IoIosPin"


class IoIosPint(rx.Component):
    library = "react-icons/io"
    tag = "IoIosPint"


class IoIosPizza(rx.Component):
    library = "react-icons/io"
    tag = "IoIosPizza"


class IoIosPlanet(rx.Component):
    library = "react-icons/io"
    tag = "IoIosPlanet"


class IoIosPlayCircle(rx.Component):
    library = "react-icons/io"
    tag = "IoIosPlayCircle"


class IoIosPlay(rx.Component):
    library = "react-icons/io"
    tag = "IoIosPlay"


class IoIosPodium(rx.Component):
    library = "react-icons/io"
    tag = "IoIosPodium"


class IoIosPower(rx.Component):
    library = "react-icons/io"
    tag = "IoIosPower"


class IoIosPricetag(rx.Component):
    library = "react-icons/io"
    tag = "IoIosPricetag"


class IoIosPricetags(rx.Component):
    library = "react-icons/io"
    tag = "IoIosPricetags"


class IoIosPrint(rx.Component):
    library = "react-icons/io"
    tag = "IoIosPrint"


class IoIosPulse(rx.Component):
    library = "react-icons/io"
    tag = "IoIosPulse"


class IoIosQrScanner(rx.Component):
    library = "react-icons/io"
    tag = "IoIosQrScanner"


class IoIosQuote(rx.Component):
    library = "react-icons/io"
    tag = "IoIosQuote"


class IoIosRadioButtonOff(rx.Component):
    library = "react-icons/io"
    tag = "IoIosRadioButtonOff"


class IoIosRadioButtonOn(rx.Component):
    library = "react-icons/io"
    tag = "IoIosRadioButtonOn"


class IoIosRadio(rx.Component):
    library = "react-icons/io"
    tag = "IoIosRadio"


class IoIosRainy(rx.Component):
    library = "react-icons/io"
    tag = "IoIosRainy"


class IoIosRecording(rx.Component):
    library = "react-icons/io"
    tag = "IoIosRecording"


class IoIosRedo(rx.Component):
    library = "react-icons/io"
    tag = "IoIosRedo"


class IoIosRefreshCircle(rx.Component):
    library = "react-icons/io"
    tag = "IoIosRefreshCircle"


class IoIosRefresh(rx.Component):
    library = "react-icons/io"
    tag = "IoIosRefresh"


class IoIosRemoveCircleOutline(rx.Component):
    library = "react-icons/io"
    tag = "IoIosRemoveCircleOutline"


class IoIosRemoveCircle(rx.Component):
    library = "react-icons/io"
    tag = "IoIosRemoveCircle"


class IoIosRemove(rx.Component):
    library = "react-icons/io"
    tag = "IoIosRemove"


class IoIosReorder(rx.Component):
    library = "react-icons/io"
    tag = "IoIosReorder"


class IoIosRepeat(rx.Component):
    library = "react-icons/io"
    tag = "IoIosRepeat"


class IoIosResize(rx.Component):
    library = "react-icons/io"
    tag = "IoIosResize"


class IoIosRestaurant(rx.Component):
    library = "react-icons/io"
    tag = "IoIosRestaurant"


class IoIosReturnLeft(rx.Component):
    library = "react-icons/io"
    tag = "IoIosReturnLeft"


class IoIosReturnRight(rx.Component):
    library = "react-icons/io"
    tag = "IoIosReturnRight"


class IoIosReverseCamera(rx.Component):
    library = "react-icons/io"
    tag = "IoIosReverseCamera"


class IoIosRewind(rx.Component):
    library = "react-icons/io"
    tag = "IoIosRewind"


class IoIosRibbon(rx.Component):
    library = "react-icons/io"
    tag = "IoIosRibbon"


class IoIosRocket(rx.Component):
    library = "react-icons/io"
    tag = "IoIosRocket"


class IoIosRose(rx.Component):
    library = "react-icons/io"
    tag = "IoIosRose"


class IoIosSad(rx.Component):
    library = "react-icons/io"
    tag = "IoIosSad"


class IoIosSave(rx.Component):
    library = "react-icons/io"
    tag = "IoIosSave"


class IoIosSchool(rx.Component):
    library = "react-icons/io"
    tag = "IoIosSchool"


class IoIosSearch(rx.Component):
    library = "react-icons/io"
    tag = "IoIosSearch"


class IoIosSend(rx.Component):
    library = "react-icons/io"
    tag = "IoIosSend"


class IoIosSettings(rx.Component):
    library = "react-icons/io"
    tag = "IoIosSettings"


class IoIosShareAlt(rx.Component):
    library = "react-icons/io"
    tag = "IoIosShareAlt"


class IoIosShare(rx.Component):
    library = "react-icons/io"
    tag = "IoIosShare"


class IoIosShirt(rx.Component):
    library = "react-icons/io"
    tag = "IoIosShirt"


class IoIosShuffle(rx.Component):
    library = "react-icons/io"
    tag = "IoIosShuffle"


class IoIosSkipBackward(rx.Component):
    library = "react-icons/io"
    tag = "IoIosSkipBackward"


class IoIosSkipForward(rx.Component):
    library = "react-icons/io"
    tag = "IoIosSkipForward"


class IoIosSnow(rx.Component):
    library = "react-icons/io"
    tag = "IoIosSnow"


class IoIosSpeedometer(rx.Component):
    library = "react-icons/io"
    tag = "IoIosSpeedometer"


class IoIosSquareOutline(rx.Component):
    library = "react-icons/io"
    tag = "IoIosSquareOutline"


class IoIosSquare(rx.Component):
    library = "react-icons/io"
    tag = "IoIosSquare"


class IoIosStarHalf(rx.Component):
    library = "react-icons/io"
    tag = "IoIosStarHalf"


class IoIosStarOutline(rx.Component):
    library = "react-icons/io"
    tag = "IoIosStarOutline"


class IoIosStar(rx.Component):
    library = "react-icons/io"
    tag = "IoIosStar"


class IoIosStats(rx.Component):
    library = "react-icons/io"
    tag = "IoIosStats"


class IoIosStopwatch(rx.Component):
    library = "react-icons/io"
    tag = "IoIosStopwatch"


class IoIosSubway(rx.Component):
    library = "react-icons/io"
    tag = "IoIosSubway"


class IoIosSunny(rx.Component):
    library = "react-icons/io"
    tag = "IoIosSunny"


class IoIosSwap(rx.Component):
    library = "react-icons/io"
    tag = "IoIosSwap"


class IoIosSwitch(rx.Component):
    library = "react-icons/io"
    tag = "IoIosSwitch"


class IoIosSync(rx.Component):
    library = "react-icons/io"
    tag = "IoIosSync"


class IoIosTabletLandscape(rx.Component):
    library = "react-icons/io"
    tag = "IoIosTabletLandscape"


class IoIosTabletPortrait(rx.Component):
    library = "react-icons/io"
    tag = "IoIosTabletPortrait"


class IoIosTennisball(rx.Component):
    library = "react-icons/io"
    tag = "IoIosTennisball"


class IoIosText(rx.Component):
    library = "react-icons/io"
    tag = "IoIosText"


class IoIosThermometer(rx.Component):
    library = "react-icons/io"
    tag = "IoIosThermometer"


class IoIosThumbsDown(rx.Component):
    library = "react-icons/io"
    tag = "IoIosThumbsDown"


class IoIosThumbsUp(rx.Component):
    library = "react-icons/io"
    tag = "IoIosThumbsUp"


class IoIosThunderstorm(rx.Component):
    library = "react-icons/io"
    tag = "IoIosThunderstorm"


class IoIosTime(rx.Component):
    library = "react-icons/io"
    tag = "IoIosTime"


class IoIosTimer(rx.Component):
    library = "react-icons/io"
    tag = "IoIosTimer"


class IoIosToday(rx.Component):
    library = "react-icons/io"
    tag = "IoIosToday"


class IoIosTrain(rx.Component):
    library = "react-icons/io"
    tag = "IoIosTrain"


class IoIosTransgender(rx.Component):
    library = "react-icons/io"
    tag = "IoIosTransgender"


class IoIosTrash(rx.Component):
    library = "react-icons/io"
    tag = "IoIosTrash"


class IoIosTrendingDown(rx.Component):
    library = "react-icons/io"
    tag = "IoIosTrendingDown"


class IoIosTrendingUp(rx.Component):
    library = "react-icons/io"
    tag = "IoIosTrendingUp"


class IoIosTrophy(rx.Component):
    library = "react-icons/io"
    tag = "IoIosTrophy"


class IoIosTv(rx.Component):
    library = "react-icons/io"
    tag = "IoIosTv"


class IoIosUmbrella(rx.Component):
    library = "react-icons/io"
    tag = "IoIosUmbrella"


class IoIosUndo(rx.Component):
    library = "react-icons/io"
    tag = "IoIosUndo"


class IoIosUnlock(rx.Component):
    library = "react-icons/io"
    tag = "IoIosUnlock"


class IoIosVideocam(rx.Component):
    library = "react-icons/io"
    tag = "IoIosVideocam"


class IoIosVolumeHigh(rx.Component):
    library = "react-icons/io"
    tag = "IoIosVolumeHigh"


class IoIosVolumeLow(rx.Component):
    library = "react-icons/io"
    tag = "IoIosVolumeLow"


class IoIosVolumeMute(rx.Component):
    library = "react-icons/io"
    tag = "IoIosVolumeMute"


class IoIosVolumeOff(rx.Component):
    library = "react-icons/io"
    tag = "IoIosVolumeOff"


class IoIosWalk(rx.Component):
    library = "react-icons/io"
    tag = "IoIosWalk"


class IoIosWallet(rx.Component):
    library = "react-icons/io"
    tag = "IoIosWallet"


class IoIosWarning(rx.Component):
    library = "react-icons/io"
    tag = "IoIosWarning"


class IoIosWatch(rx.Component):
    library = "react-icons/io"
    tag = "IoIosWatch"


class IoIosWater(rx.Component):
    library = "react-icons/io"
    tag = "IoIosWater"


class IoIosWifi(rx.Component):
    library = "react-icons/io"
    tag = "IoIosWifi"


class IoIosWine(rx.Component):
    library = "react-icons/io"
    tag = "IoIosWine"


class IoIosWoman(rx.Component):
    library = "react-icons/io"
    tag = "IoIosWoman"


class IoLogoAndroid(rx.Component):
    library = "react-icons/io"
    tag = "IoLogoAndroid"


class IoLogoAngular(rx.Component):
    library = "react-icons/io"
    tag = "IoLogoAngular"


class IoLogoApple(rx.Component):
    library = "react-icons/io"
    tag = "IoLogoApple"


class IoLogoBitbucket(rx.Component):
    library = "react-icons/io"
    tag = "IoLogoBitbucket"


class IoLogoBitcoin(rx.Component):
    library = "react-icons/io"
    tag = "IoLogoBitcoin"


class IoLogoBuffer(rx.Component):
    library = "react-icons/io"
    tag = "IoLogoBuffer"


class IoLogoChrome(rx.Component):
    library = "react-icons/io"
    tag = "IoLogoChrome"


class IoLogoClosedCaptioning(rx.Component):
    library = "react-icons/io"
    tag = "IoLogoClosedCaptioning"


class IoLogoCodepen(rx.Component):
    library = "react-icons/io"
    tag = "IoLogoCodepen"


class IoLogoCss3(rx.Component):
    library = "react-icons/io"
    tag = "IoLogoCss3"


class IoLogoDesignernews(rx.Component):
    library = "react-icons/io"
    tag = "IoLogoDesignernews"


class IoLogoDribbble(rx.Component):
    library = "react-icons/io"
    tag = "IoLogoDribbble"


class IoLogoDropbox(rx.Component):
    library = "react-icons/io"
    tag = "IoLogoDropbox"


class IoLogoEuro(rx.Component):
    library = "react-icons/io"
    tag = "IoLogoEuro"


class IoLogoFacebook(rx.Component):
    library = "react-icons/io"
    tag = "IoLogoFacebook"


class IoLogoFlickr(rx.Component):
    library = "react-icons/io"
    tag = "IoLogoFlickr"


class IoLogoFoursquare(rx.Component):
    library = "react-icons/io"
    tag = "IoLogoFoursquare"


class IoLogoFreebsdDevil(rx.Component):
    library = "react-icons/io"
    tag = "IoLogoFreebsdDevil"


class IoLogoGameControllerA(rx.Component):
    library = "react-icons/io"
    tag = "IoLogoGameControllerA"


class IoLogoGameControllerB(rx.Component):
    library = "react-icons/io"
    tag = "IoLogoGameControllerB"


class IoLogoGithub(rx.Component):
    library = "react-icons/io"
    tag = "IoLogoGithub"


class IoLogoGoogle(rx.Component):
    library = "react-icons/io"
    tag = "IoLogoGoogle"


class IoLogoGoogleplus(rx.Component):
    library = "react-icons/io"
    tag = "IoLogoGoogleplus"


class IoLogoHackernews(rx.Component):
    library = "react-icons/io"
    tag = "IoLogoHackernews"


class IoLogoHtml5(rx.Component):
    library = "react-icons/io"
    tag = "IoLogoHtml5"


class IoLogoInstagram(rx.Component):
    library = "react-icons/io"
    tag = "IoLogoInstagram"


class IoLogoIonic(rx.Component):
    library = "react-icons/io"
    tag = "IoLogoIonic"


class IoLogoIonitron(rx.Component):
    library = "react-icons/io"
    tag = "IoLogoIonitron"


class IoLogoJavascript(rx.Component):
    library = "react-icons/io"
    tag = "IoLogoJavascript"


class IoLogoLinkedin(rx.Component):
    library = "react-icons/io"
    tag = "IoLogoLinkedin"


class IoLogoMarkdown(rx.Component):
    library = "react-icons/io"
    tag = "IoLogoMarkdown"


class IoLogoModelS(rx.Component):
    library = "react-icons/io"
    tag = "IoLogoModelS"


class IoLogoNoSmoking(rx.Component):
    library = "react-icons/io"
    tag = "IoLogoNoSmoking"


class IoLogoNodejs(rx.Component):
    library = "react-icons/io"
    tag = "IoLogoNodejs"


class IoLogoNpm(rx.Component):
    library = "react-icons/io"
    tag = "IoLogoNpm"


class IoLogoOctocat(rx.Component):
    library = "react-icons/io"
    tag = "IoLogoOctocat"


class IoLogoPinterest(rx.Component):
    library = "react-icons/io"
    tag = "IoLogoPinterest"


class IoLogoPlaystation(rx.Component):
    library = "react-icons/io"
    tag = "IoLogoPlaystation"


class IoLogoPolymer(rx.Component):
    library = "react-icons/io"
    tag = "IoLogoPolymer"


class IoLogoPython(rx.Component):
    library = "react-icons/io"
    tag = "IoLogoPython"


class IoLogoReddit(rx.Component):
    library = "react-icons/io"
    tag = "IoLogoReddit"


class IoLogoRss(rx.Component):
    library = "react-icons/io"
    tag = "IoLogoRss"


class IoLogoSass(rx.Component):
    library = "react-icons/io"
    tag = "IoLogoSass"


class IoLogoSkype(rx.Component):
    library = "react-icons/io"
    tag = "IoLogoSkype"


class IoLogoSlack(rx.Component):
    library = "react-icons/io"
    tag = "IoLogoSlack"


class IoLogoSnapchat(rx.Component):
    library = "react-icons/io"
    tag = "IoLogoSnapchat"


class IoLogoSteam(rx.Component):
    library = "react-icons/io"
    tag = "IoLogoSteam"


class IoLogoTumblr(rx.Component):
    library = "react-icons/io"
    tag = "IoLogoTumblr"


class IoLogoTux(rx.Component):
    library = "react-icons/io"
    tag = "IoLogoTux"


class IoLogoTwitch(rx.Component):
    library = "react-icons/io"
    tag = "IoLogoTwitch"


class IoLogoTwitter(rx.Component):
    library = "react-icons/io"
    tag = "IoLogoTwitter"


class IoLogoUsd(rx.Component):
    library = "react-icons/io"
    tag = "IoLogoUsd"


class IoLogoVimeo(rx.Component):
    library = "react-icons/io"
    tag = "IoLogoVimeo"


class IoLogoVk(rx.Component):
    library = "react-icons/io"
    tag = "IoLogoVk"


class IoLogoWhatsapp(rx.Component):
    library = "react-icons/io"
    tag = "IoLogoWhatsapp"


class IoLogoWindows(rx.Component):
    library = "react-icons/io"
    tag = "IoLogoWindows"


class IoLogoWordpress(rx.Component):
    library = "react-icons/io"
    tag = "IoLogoWordpress"


class IoLogoXbox(rx.Component):
    library = "react-icons/io"
    tag = "IoLogoXbox"


class IoLogoXing(rx.Component):
    library = "react-icons/io"
    tag = "IoLogoXing"


class IoLogoYahoo(rx.Component):
    library = "react-icons/io"
    tag = "IoLogoYahoo"


class IoLogoYen(rx.Component):
    library = "react-icons/io"
    tag = "IoLogoYen"


class IoLogoYoutube(rx.Component):
    library = "react-icons/io"
    tag = "IoLogoYoutube"


class IoMdAddCircleOutline(rx.Component):
    library = "react-icons/io"
    tag = "IoMdAddCircleOutline"


class IoMdAddCircle(rx.Component):
    library = "react-icons/io"
    tag = "IoMdAddCircle"


class IoMdAdd(rx.Component):
    library = "react-icons/io"
    tag = "IoMdAdd"


class IoMdAirplane(rx.Component):
    library = "react-icons/io"
    tag = "IoMdAirplane"


class IoMdAlarm(rx.Component):
    library = "react-icons/io"
    tag = "IoMdAlarm"


class IoMdAlbums(rx.Component):
    library = "react-icons/io"
    tag = "IoMdAlbums"


class IoMdAlert(rx.Component):
    library = "react-icons/io"
    tag = "IoMdAlert"


class IoMdAmericanFootball(rx.Component):
    library = "react-icons/io"
    tag = "IoMdAmericanFootball"


class IoMdAnalytics(rx.Component):
    library = "react-icons/io"
    tag = "IoMdAnalytics"


class IoMdAperture(rx.Component):
    library = "react-icons/io"
    tag = "IoMdAperture"


class IoMdApps(rx.Component):
    library = "react-icons/io"
    tag = "IoMdApps"


class IoMdAppstore(rx.Component):
    library = "react-icons/io"
    tag = "IoMdAppstore"


class IoMdArchive(rx.Component):
    library = "react-icons/io"
    tag = "IoMdArchive"


class IoMdArrowBack(rx.Component):
    library = "react-icons/io"
    tag = "IoMdArrowBack"


class IoMdArrowDown(rx.Component):
    library = "react-icons/io"
    tag = "IoMdArrowDown"


class IoMdArrowDropdownCircle(rx.Component):
    library = "react-icons/io"
    tag = "IoMdArrowDropdownCircle"


class IoMdArrowDropdown(rx.Component):
    library = "react-icons/io"
    tag = "IoMdArrowDropdown"


class IoMdArrowDropleftCircle(rx.Component):
    library = "react-icons/io"
    tag = "IoMdArrowDropleftCircle"


class IoMdArrowDropleft(rx.Component):
    library = "react-icons/io"
    tag = "IoMdArrowDropleft"


class IoMdArrowDroprightCircle(rx.Component):
    library = "react-icons/io"
    tag = "IoMdArrowDroprightCircle"


class IoMdArrowDropright(rx.Component):
    library = "react-icons/io"
    tag = "IoMdArrowDropright"


class IoMdArrowDropupCircle(rx.Component):
    library = "react-icons/io"
    tag = "IoMdArrowDropupCircle"


class IoMdArrowDropup(rx.Component):
    library = "react-icons/io"
    tag = "IoMdArrowDropup"


class IoMdArrowForward(rx.Component):
    library = "react-icons/io"
    tag = "IoMdArrowForward"


class IoMdArrowRoundBack(rx.Component):
    library = "react-icons/io"
    tag = "IoMdArrowRoundBack"


class IoMdArrowRoundDown(rx.Component):
    library = "react-icons/io"
    tag = "IoMdArrowRoundDown"


class IoMdArrowRoundForward(rx.Component):
    library = "react-icons/io"
    tag = "IoMdArrowRoundForward"


class IoMdArrowRoundUp(rx.Component):
    library = "react-icons/io"
    tag = "IoMdArrowRoundUp"


class IoMdArrowUp(rx.Component):
    library = "react-icons/io"
    tag = "IoMdArrowUp"


class IoMdAt(rx.Component):
    library = "react-icons/io"
    tag = "IoMdAt"


class IoMdAttach(rx.Component):
    library = "react-icons/io"
    tag = "IoMdAttach"


class IoMdBackspace(rx.Component):
    library = "react-icons/io"
    tag = "IoMdBackspace"


class IoMdBarcode(rx.Component):
    library = "react-icons/io"
    tag = "IoMdBarcode"


class IoMdBaseball(rx.Component):
    library = "react-icons/io"
    tag = "IoMdBaseball"


class IoMdBasket(rx.Component):
    library = "react-icons/io"
    tag = "IoMdBasket"


class IoMdBasketball(rx.Component):
    library = "react-icons/io"
    tag = "IoMdBasketball"


class IoMdBatteryCharging(rx.Component):
    library = "react-icons/io"
    tag = "IoMdBatteryCharging"


class IoMdBatteryDead(rx.Component):
    library = "react-icons/io"
    tag = "IoMdBatteryDead"


class IoMdBatteryFull(rx.Component):
    library = "react-icons/io"
    tag = "IoMdBatteryFull"


class IoMdBeaker(rx.Component):
    library = "react-icons/io"
    tag = "IoMdBeaker"


class IoMdBed(rx.Component):
    library = "react-icons/io"
    tag = "IoMdBed"


class IoMdBeer(rx.Component):
    library = "react-icons/io"
    tag = "IoMdBeer"


class IoMdBicycle(rx.Component):
    library = "react-icons/io"
    tag = "IoMdBicycle"


class IoMdBluetooth(rx.Component):
    library = "react-icons/io"
    tag = "IoMdBluetooth"


class IoMdBoat(rx.Component):
    library = "react-icons/io"
    tag = "IoMdBoat"


class IoMdBody(rx.Component):
    library = "react-icons/io"
    tag = "IoMdBody"


class IoMdBonfire(rx.Component):
    library = "react-icons/io"
    tag = "IoMdBonfire"


class IoMdBook(rx.Component):
    library = "react-icons/io"
    tag = "IoMdBook"


class IoMdBookmark(rx.Component):
    library = "react-icons/io"
    tag = "IoMdBookmark"


class IoMdBookmarks(rx.Component):
    library = "react-icons/io"
    tag = "IoMdBookmarks"


class IoMdBowtie(rx.Component):
    library = "react-icons/io"
    tag = "IoMdBowtie"


class IoMdBriefcase(rx.Component):
    library = "react-icons/io"
    tag = "IoMdBriefcase"


class IoMdBrowsers(rx.Component):
    library = "react-icons/io"
    tag = "IoMdBrowsers"


class IoMdBrush(rx.Component):
    library = "react-icons/io"
    tag = "IoMdBrush"


class IoMdBug(rx.Component):
    library = "react-icons/io"
    tag = "IoMdBug"


class IoMdBuild(rx.Component):
    library = "react-icons/io"
    tag = "IoMdBuild"


class IoMdBulb(rx.Component):
    library = "react-icons/io"
    tag = "IoMdBulb"


class IoMdBus(rx.Component):
    library = "react-icons/io"
    tag = "IoMdBus"


class IoMdBusiness(rx.Component):
    library = "react-icons/io"
    tag = "IoMdBusiness"


class IoMdCafe(rx.Component):
    library = "react-icons/io"
    tag = "IoMdCafe"


class IoMdCalculator(rx.Component):
    library = "react-icons/io"
    tag = "IoMdCalculator"


class IoMdCalendar(rx.Component):
    library = "react-icons/io"
    tag = "IoMdCalendar"


class IoMdCall(rx.Component):
    library = "react-icons/io"
    tag = "IoMdCall"


class IoMdCamera(rx.Component):
    library = "react-icons/io"
    tag = "IoMdCamera"


class IoMdCar(rx.Component):
    library = "react-icons/io"
    tag = "IoMdCar"


class IoMdCard(rx.Component):
    library = "react-icons/io"
    tag = "IoMdCard"


class IoMdCart(rx.Component):
    library = "react-icons/io"
    tag = "IoMdCart"


class IoMdCash(rx.Component):
    library = "react-icons/io"
    tag = "IoMdCash"


class IoMdCellular(rx.Component):
    library = "react-icons/io"
    tag = "IoMdCellular"


class IoMdChatboxes(rx.Component):
    library = "react-icons/io"
    tag = "IoMdChatboxes"


class IoMdChatbubbles(rx.Component):
    library = "react-icons/io"
    tag = "IoMdChatbubbles"


class IoMdCheckboxOutline(rx.Component):
    library = "react-icons/io"
    tag = "IoMdCheckboxOutline"


class IoMdCheckbox(rx.Component):
    library = "react-icons/io"
    tag = "IoMdCheckbox"


class IoMdCheckmarkCircleOutline(rx.Component):
    library = "react-icons/io"
    tag = "IoMdCheckmarkCircleOutline"


class IoMdCheckmarkCircle(rx.Component):
    library = "react-icons/io"
    tag = "IoMdCheckmarkCircle"


class IoMdCheckmark(rx.Component):
    library = "react-icons/io"
    tag = "IoMdCheckmark"


class IoMdClipboard(rx.Component):
    library = "react-icons/io"
    tag = "IoMdClipboard"


class IoMdClock(rx.Component):
    library = "react-icons/io"
    tag = "IoMdClock"


class IoMdCloseCircleOutline(rx.Component):
    library = "react-icons/io"
    tag = "IoMdCloseCircleOutline"


class IoMdCloseCircle(rx.Component):
    library = "react-icons/io"
    tag = "IoMdCloseCircle"


class IoMdClose(rx.Component):
    library = "react-icons/io"
    tag = "IoMdClose"


class IoMdCloudCircle(rx.Component):
    library = "react-icons/io"
    tag = "IoMdCloudCircle"


class IoMdCloudDone(rx.Component):
    library = "react-icons/io"
    tag = "IoMdCloudDone"


class IoMdCloudDownload(rx.Component):
    library = "react-icons/io"
    tag = "IoMdCloudDownload"


class IoMdCloudOutline(rx.Component):
    library = "react-icons/io"
    tag = "IoMdCloudOutline"


class IoMdCloudUpload(rx.Component):
    library = "react-icons/io"
    tag = "IoMdCloudUpload"


class IoMdCloud(rx.Component):
    library = "react-icons/io"
    tag = "IoMdCloud"


class IoMdCloudyNight(rx.Component):
    library = "react-icons/io"
    tag = "IoMdCloudyNight"


class IoMdCloudy(rx.Component):
    library = "react-icons/io"
    tag = "IoMdCloudy"


class IoMdCodeDownload(rx.Component):
    library = "react-icons/io"
    tag = "IoMdCodeDownload"


class IoMdCodeWorking(rx.Component):
    library = "react-icons/io"
    tag = "IoMdCodeWorking"


class IoMdCode(rx.Component):
    library = "react-icons/io"
    tag = "IoMdCode"


class IoMdCog(rx.Component):
    library = "react-icons/io"
    tag = "IoMdCog"


class IoMdColorFill(rx.Component):
    library = "react-icons/io"
    tag = "IoMdColorFill"


class IoMdColorFilter(rx.Component):
    library = "react-icons/io"
    tag = "IoMdColorFilter"


class IoMdColorPalette(rx.Component):
    library = "react-icons/io"
    tag = "IoMdColorPalette"


class IoMdColorWand(rx.Component):
    library = "react-icons/io"
    tag = "IoMdColorWand"


class IoMdCompass(rx.Component):
    library = "react-icons/io"
    tag = "IoMdCompass"


class IoMdConstruct(rx.Component):
    library = "react-icons/io"
    tag = "IoMdConstruct"


class IoMdContact(rx.Component):
    library = "react-icons/io"
    tag = "IoMdContact"


class IoMdContacts(rx.Component):
    library = "react-icons/io"
    tag = "IoMdContacts"


class IoMdContract(rx.Component):
    library = "react-icons/io"
    tag = "IoMdContract"


class IoMdContrast(rx.Component):
    library = "react-icons/io"
    tag = "IoMdContrast"


class IoMdCopy(rx.Component):
    library = "react-icons/io"
    tag = "IoMdCopy"


class IoMdCreate(rx.Component):
    library = "react-icons/io"
    tag = "IoMdCreate"


class IoMdCrop(rx.Component):
    library = "react-icons/io"
    tag = "IoMdCrop"


class IoMdCube(rx.Component):
    library = "react-icons/io"
    tag = "IoMdCube"


class IoMdCut(rx.Component):
    library = "react-icons/io"
    tag = "IoMdCut"


class IoMdDesktop(rx.Component):
    library = "react-icons/io"
    tag = "IoMdDesktop"


class IoMdDisc(rx.Component):
    library = "react-icons/io"
    tag = "IoMdDisc"


class IoMdDocument(rx.Component):
    library = "react-icons/io"
    tag = "IoMdDocument"


class IoMdDoneAll(rx.Component):
    library = "react-icons/io"
    tag = "IoMdDoneAll"


class IoMdDownload(rx.Component):
    library = "react-icons/io"
    tag = "IoMdDownload"


class IoMdEasel(rx.Component):
    library = "react-icons/io"
    tag = "IoMdEasel"


class IoMdEgg(rx.Component):
    library = "react-icons/io"
    tag = "IoMdEgg"


class IoMdExit(rx.Component):
    library = "react-icons/io"
    tag = "IoMdExit"


class IoMdExpand(rx.Component):
    library = "react-icons/io"
    tag = "IoMdExpand"


class IoMdEyeOff(rx.Component):
    library = "react-icons/io"
    tag = "IoMdEyeOff"


class IoMdEye(rx.Component):
    library = "react-icons/io"
    tag = "IoMdEye"


class IoMdFastforward(rx.Component):
    library = "react-icons/io"
    tag = "IoMdFastforward"


class IoMdFemale(rx.Component):
    library = "react-icons/io"
    tag = "IoMdFemale"


class IoMdFiling(rx.Component):
    library = "react-icons/io"
    tag = "IoMdFiling"


class IoMdFilm(rx.Component):
    library = "react-icons/io"
    tag = "IoMdFilm"


class IoMdFingerPrint(rx.Component):
    library = "react-icons/io"
    tag = "IoMdFingerPrint"


class IoMdFitness(rx.Component):
    library = "react-icons/io"
    tag = "IoMdFitness"


class IoMdFlag(rx.Component):
    library = "react-icons/io"
    tag = "IoMdFlag"


class IoMdFlame(rx.Component):
    library = "react-icons/io"
    tag = "IoMdFlame"


class IoMdFlashOff(rx.Component):
    library = "react-icons/io"
    tag = "IoMdFlashOff"


class IoMdFlash(rx.Component):
    library = "react-icons/io"
    tag = "IoMdFlash"


class IoMdFlashlight(rx.Component):
    library = "react-icons/io"
    tag = "IoMdFlashlight"


class IoMdFlask(rx.Component):
    library = "react-icons/io"
    tag = "IoMdFlask"


class IoMdFlower(rx.Component):
    library = "react-icons/io"
    tag = "IoMdFlower"


class IoMdFolderOpen(rx.Component):
    library = "react-icons/io"
    tag = "IoMdFolderOpen"


class IoMdFolder(rx.Component):
    library = "react-icons/io"
    tag = "IoMdFolder"


class IoMdFootball(rx.Component):
    library = "react-icons/io"
    tag = "IoMdFootball"


class IoMdFunnel(rx.Component):
    library = "react-icons/io"
    tag = "IoMdFunnel"


class IoMdGift(rx.Component):
    library = "react-icons/io"
    tag = "IoMdGift"


class IoMdGitBranch(rx.Component):
    library = "react-icons/io"
    tag = "IoMdGitBranch"


class IoMdGitCommit(rx.Component):
    library = "react-icons/io"
    tag = "IoMdGitCommit"


class IoMdGitCompare(rx.Component):
    library = "react-icons/io"
    tag = "IoMdGitCompare"


class IoMdGitMerge(rx.Component):
    library = "react-icons/io"
    tag = "IoMdGitMerge"


class IoMdGitNetwork(rx.Component):
    library = "react-icons/io"
    tag = "IoMdGitNetwork"


class IoMdGitPullRequest(rx.Component):
    library = "react-icons/io"
    tag = "IoMdGitPullRequest"


class IoMdGlasses(rx.Component):
    library = "react-icons/io"
    tag = "IoMdGlasses"


class IoMdGlobe(rx.Component):
    library = "react-icons/io"
    tag = "IoMdGlobe"


class IoMdGrid(rx.Component):
    library = "react-icons/io"
    tag = "IoMdGrid"


class IoMdHammer(rx.Component):
    library = "react-icons/io"
    tag = "IoMdHammer"


class IoMdHand(rx.Component):
    library = "react-icons/io"
    tag = "IoMdHand"


class IoMdHappy(rx.Component):
    library = "react-icons/io"
    tag = "IoMdHappy"


class IoMdHeadset(rx.Component):
    library = "react-icons/io"
    tag = "IoMdHeadset"


class IoMdHeartDislike(rx.Component):
    library = "react-icons/io"
    tag = "IoMdHeartDislike"


class IoMdHeartEmpty(rx.Component):
    library = "react-icons/io"
    tag = "IoMdHeartEmpty"


class IoMdHeartHalf(rx.Component):
    library = "react-icons/io"
    tag = "IoMdHeartHalf"


class IoMdHeart(rx.Component):
    library = "react-icons/io"
    tag = "IoMdHeart"


class IoMdHelpBuoy(rx.Component):
    library = "react-icons/io"
    tag = "IoMdHelpBuoy"


class IoMdHelpCircleOutline(rx.Component):
    library = "react-icons/io"
    tag = "IoMdHelpCircleOutline"


class IoMdHelpCircle(rx.Component):
    library = "react-icons/io"
    tag = "IoMdHelpCircle"


class IoMdHelp(rx.Component):
    library = "react-icons/io"
    tag = "IoMdHelp"


class IoMdHome(rx.Component):
    library = "react-icons/io"
    tag = "IoMdHome"


class IoMdHourglass(rx.Component):
    library = "react-icons/io"
    tag = "IoMdHourglass"


class IoMdIceCream(rx.Component):
    library = "react-icons/io"
    tag = "IoMdIceCream"


class IoMdImage(rx.Component):
    library = "react-icons/io"
    tag = "IoMdImage"


class IoMdImages(rx.Component):
    library = "react-icons/io"
    tag = "IoMdImages"


class IoMdInfinite(rx.Component):
    library = "react-icons/io"
    tag = "IoMdInfinite"


class IoMdInformationCircleOutline(rx.Component):
    library = "react-icons/io"
    tag = "IoMdInformationCircleOutline"


class IoMdInformationCircle(rx.Component):
    library = "react-icons/io"
    tag = "IoMdInformationCircle"


class IoMdInformation(rx.Component):
    library = "react-icons/io"
    tag = "IoMdInformation"


class IoMdJet(rx.Component):
    library = "react-icons/io"
    tag = "IoMdJet"


class IoMdJournal(rx.Component):
    library = "react-icons/io"
    tag = "IoMdJournal"


class IoMdKey(rx.Component):
    library = "react-icons/io"
    tag = "IoMdKey"


class IoMdKeypad(rx.Component):
    library = "react-icons/io"
    tag = "IoMdKeypad"


class IoMdLaptop(rx.Component):
    library = "react-icons/io"
    tag = "IoMdLaptop"


class IoMdLeaf(rx.Component):
    library = "react-icons/io"
    tag = "IoMdLeaf"


class IoMdLink(rx.Component):
    library = "react-icons/io"
    tag = "IoMdLink"


class IoMdListBox(rx.Component):
    library = "react-icons/io"
    tag = "IoMdListBox"


class IoMdList(rx.Component):
    library = "react-icons/io"
    tag = "IoMdList"


class IoMdLocate(rx.Component):
    library = "react-icons/io"
    tag = "IoMdLocate"


class IoMdLock(rx.Component):
    library = "react-icons/io"
    tag = "IoMdLock"


class IoMdLogIn(rx.Component):
    library = "react-icons/io"
    tag = "IoMdLogIn"


class IoMdLogOut(rx.Component):
    library = "react-icons/io"
    tag = "IoMdLogOut"


class IoMdMagnet(rx.Component):
    library = "react-icons/io"
    tag = "IoMdMagnet"


class IoMdMailOpen(rx.Component):
    library = "react-icons/io"
    tag = "IoMdMailOpen"


class IoMdMailUnread(rx.Component):
    library = "react-icons/io"
    tag = "IoMdMailUnread"


class IoMdMail(rx.Component):
    library = "react-icons/io"
    tag = "IoMdMail"


class IoMdMale(rx.Component):
    library = "react-icons/io"
    tag = "IoMdMale"


class IoMdMan(rx.Component):
    library = "react-icons/io"
    tag = "IoMdMan"


class IoMdMap(rx.Component):
    library = "react-icons/io"
    tag = "IoMdMap"


class IoMdMedal(rx.Component):
    library = "react-icons/io"
    tag = "IoMdMedal"


class IoMdMedical(rx.Component):
    library = "react-icons/io"
    tag = "IoMdMedical"


class IoMdMedkit(rx.Component):
    library = "react-icons/io"
    tag = "IoMdMedkit"


class IoMdMegaphone(rx.Component):
    library = "react-icons/io"
    tag = "IoMdMegaphone"


class IoMdMenu(rx.Component):
    library = "react-icons/io"
    tag = "IoMdMenu"


class IoMdMicOff(rx.Component):
    library = "react-icons/io"
    tag = "IoMdMicOff"


class IoMdMic(rx.Component):
    library = "react-icons/io"
    tag = "IoMdMic"


class IoMdMicrophone(rx.Component):
    library = "react-icons/io"
    tag = "IoMdMicrophone"


class IoMdMoon(rx.Component):
    library = "react-icons/io"
    tag = "IoMdMoon"


class IoMdMore(rx.Component):
    library = "react-icons/io"
    tag = "IoMdMore"


class IoMdMove(rx.Component):
    library = "react-icons/io"
    tag = "IoMdMove"


class IoMdMusicalNote(rx.Component):
    library = "react-icons/io"
    tag = "IoMdMusicalNote"


class IoMdMusicalNotes(rx.Component):
    library = "react-icons/io"
    tag = "IoMdMusicalNotes"


class IoMdNavigate(rx.Component):
    library = "react-icons/io"
    tag = "IoMdNavigate"


class IoMdNotificationsOff(rx.Component):
    library = "react-icons/io"
    tag = "IoMdNotificationsOff"


class IoMdNotificationsOutline(rx.Component):
    library = "react-icons/io"
    tag = "IoMdNotificationsOutline"


class IoMdNotifications(rx.Component):
    library = "react-icons/io"
    tag = "IoMdNotifications"


class IoMdNuclear(rx.Component):
    library = "react-icons/io"
    tag = "IoMdNuclear"


class IoMdNutrition(rx.Component):
    library = "react-icons/io"
    tag = "IoMdNutrition"


class IoMdOpen(rx.Component):
    library = "react-icons/io"
    tag = "IoMdOpen"


class IoMdOptions(rx.Component):
    library = "react-icons/io"
    tag = "IoMdOptions"


class IoMdOutlet(rx.Component):
    library = "react-icons/io"
    tag = "IoMdOutlet"


class IoMdPaperPlane(rx.Component):
    library = "react-icons/io"
    tag = "IoMdPaperPlane"


class IoMdPaper(rx.Component):
    library = "react-icons/io"
    tag = "IoMdPaper"


class IoMdPartlySunny(rx.Component):
    library = "react-icons/io"
    tag = "IoMdPartlySunny"


class IoMdPause(rx.Component):
    library = "react-icons/io"
    tag = "IoMdPause"


class IoMdPaw(rx.Component):
    library = "react-icons/io"
    tag = "IoMdPaw"


class IoMdPeople(rx.Component):
    library = "react-icons/io"
    tag = "IoMdPeople"


class IoMdPersonAdd(rx.Component):
    library = "react-icons/io"
    tag = "IoMdPersonAdd"


class IoMdPerson(rx.Component):
    library = "react-icons/io"
    tag = "IoMdPerson"


class IoMdPhoneLandscape(rx.Component):
    library = "react-icons/io"
    tag = "IoMdPhoneLandscape"


class IoMdPhonePortrait(rx.Component):
    library = "react-icons/io"
    tag = "IoMdPhonePortrait"


class IoMdPhotos(rx.Component):
    library = "react-icons/io"
    tag = "IoMdPhotos"


class IoMdPie(rx.Component):
    library = "react-icons/io"
    tag = "IoMdPie"


class IoMdPin(rx.Component):
    library = "react-icons/io"
    tag = "IoMdPin"


class IoMdPint(rx.Component):
    library = "react-icons/io"
    tag = "IoMdPint"


class IoMdPizza(rx.Component):
    library = "react-icons/io"
    tag = "IoMdPizza"


class IoMdPlanet(rx.Component):
    library = "react-icons/io"
    tag = "IoMdPlanet"


class IoMdPlayCircle(rx.Component):
    library = "react-icons/io"
    tag = "IoMdPlayCircle"


class IoMdPlay(rx.Component):
    library = "react-icons/io"
    tag = "IoMdPlay"


class IoMdPodium(rx.Component):
    library = "react-icons/io"
    tag = "IoMdPodium"


class IoMdPower(rx.Component):
    library = "react-icons/io"
    tag = "IoMdPower"


class IoMdPricetag(rx.Component):
    library = "react-icons/io"
    tag = "IoMdPricetag"


class IoMdPricetags(rx.Component):
    library = "react-icons/io"
    tag = "IoMdPricetags"


class IoMdPrint(rx.Component):
    library = "react-icons/io"
    tag = "IoMdPrint"


class IoMdPulse(rx.Component):
    library = "react-icons/io"
    tag = "IoMdPulse"


class IoMdQrScanner(rx.Component):
    library = "react-icons/io"
    tag = "IoMdQrScanner"


class IoMdQuote(rx.Component):
    library = "react-icons/io"
    tag = "IoMdQuote"


class IoMdRadioButtonOff(rx.Component):
    library = "react-icons/io"
    tag = "IoMdRadioButtonOff"


class IoMdRadioButtonOn(rx.Component):
    library = "react-icons/io"
    tag = "IoMdRadioButtonOn"


class IoMdRadio(rx.Component):
    library = "react-icons/io"
    tag = "IoMdRadio"


class IoMdRainy(rx.Component):
    library = "react-icons/io"
    tag = "IoMdRainy"


class IoMdRecording(rx.Component):
    library = "react-icons/io"
    tag = "IoMdRecording"


class IoMdRedo(rx.Component):
    library = "react-icons/io"
    tag = "IoMdRedo"


class IoMdRefreshCircle(rx.Component):
    library = "react-icons/io"
    tag = "IoMdRefreshCircle"


class IoMdRefresh(rx.Component):
    library = "react-icons/io"
    tag = "IoMdRefresh"


class IoMdRemoveCircleOutline(rx.Component):
    library = "react-icons/io"
    tag = "IoMdRemoveCircleOutline"


class IoMdRemoveCircle(rx.Component):
    library = "react-icons/io"
    tag = "IoMdRemoveCircle"


class IoMdRemove(rx.Component):
    library = "react-icons/io"
    tag = "IoMdRemove"


class IoMdReorder(rx.Component):
    library = "react-icons/io"
    tag = "IoMdReorder"


class IoMdRepeat(rx.Component):
    library = "react-icons/io"
    tag = "IoMdRepeat"


class IoMdResize(rx.Component):
    library = "react-icons/io"
    tag = "IoMdResize"


class IoMdRestaurant(rx.Component):
    library = "react-icons/io"
    tag = "IoMdRestaurant"


class IoMdReturnLeft(rx.Component):
    library = "react-icons/io"
    tag = "IoMdReturnLeft"


class IoMdReturnRight(rx.Component):
    library = "react-icons/io"
    tag = "IoMdReturnRight"


class IoMdReverseCamera(rx.Component):
    library = "react-icons/io"
    tag = "IoMdReverseCamera"


class IoMdRewind(rx.Component):
    library = "react-icons/io"
    tag = "IoMdRewind"


class IoMdRibbon(rx.Component):
    library = "react-icons/io"
    tag = "IoMdRibbon"


class IoMdRocket(rx.Component):
    library = "react-icons/io"
    tag = "IoMdRocket"


class IoMdRose(rx.Component):
    library = "react-icons/io"
    tag = "IoMdRose"


class IoMdSad(rx.Component):
    library = "react-icons/io"
    tag = "IoMdSad"


class IoMdSave(rx.Component):
    library = "react-icons/io"
    tag = "IoMdSave"


class IoMdSchool(rx.Component):
    library = "react-icons/io"
    tag = "IoMdSchool"


class IoMdSearch(rx.Component):
    library = "react-icons/io"
    tag = "IoMdSearch"


class IoMdSend(rx.Component):
    library = "react-icons/io"
    tag = "IoMdSend"


class IoMdSettings(rx.Component):
    library = "react-icons/io"
    tag = "IoMdSettings"


class IoMdShareAlt(rx.Component):
    library = "react-icons/io"
    tag = "IoMdShareAlt"


class IoMdShare(rx.Component):
    library = "react-icons/io"
    tag = "IoMdShare"


class IoMdShirt(rx.Component):
    library = "react-icons/io"
    tag = "IoMdShirt"


class IoMdShuffle(rx.Component):
    library = "react-icons/io"
    tag = "IoMdShuffle"


class IoMdSkipBackward(rx.Component):
    library = "react-icons/io"
    tag = "IoMdSkipBackward"


class IoMdSkipForward(rx.Component):
    library = "react-icons/io"
    tag = "IoMdSkipForward"


class IoMdSnow(rx.Component):
    library = "react-icons/io"
    tag = "IoMdSnow"


class IoMdSpeedometer(rx.Component):
    library = "react-icons/io"
    tag = "IoMdSpeedometer"


class IoMdSquareOutline(rx.Component):
    library = "react-icons/io"
    tag = "IoMdSquareOutline"


class IoMdSquare(rx.Component):
    library = "react-icons/io"
    tag = "IoMdSquare"


class IoMdStarHalf(rx.Component):
    library = "react-icons/io"
    tag = "IoMdStarHalf"


class IoMdStarOutline(rx.Component):
    library = "react-icons/io"
    tag = "IoMdStarOutline"


class IoMdStar(rx.Component):
    library = "react-icons/io"
    tag = "IoMdStar"


class IoMdStats(rx.Component):
    library = "react-icons/io"
    tag = "IoMdStats"


class IoMdStopwatch(rx.Component):
    library = "react-icons/io"
    tag = "IoMdStopwatch"


class IoMdSubway(rx.Component):
    library = "react-icons/io"
    tag = "IoMdSubway"


class IoMdSunny(rx.Component):
    library = "react-icons/io"
    tag = "IoMdSunny"


class IoMdSwap(rx.Component):
    library = "react-icons/io"
    tag = "IoMdSwap"


class IoMdSwitch(rx.Component):
    library = "react-icons/io"
    tag = "IoMdSwitch"


class IoMdSync(rx.Component):
    library = "react-icons/io"
    tag = "IoMdSync"


class IoMdTabletLandscape(rx.Component):
    library = "react-icons/io"
    tag = "IoMdTabletLandscape"


class IoMdTabletPortrait(rx.Component):
    library = "react-icons/io"
    tag = "IoMdTabletPortrait"


class IoMdTennisball(rx.Component):
    library = "react-icons/io"
    tag = "IoMdTennisball"


class IoMdText(rx.Component):
    library = "react-icons/io"
    tag = "IoMdText"


class IoMdThermometer(rx.Component):
    library = "react-icons/io"
    tag = "IoMdThermometer"


class IoMdThumbsDown(rx.Component):
    library = "react-icons/io"
    tag = "IoMdThumbsDown"


class IoMdThumbsUp(rx.Component):
    library = "react-icons/io"
    tag = "IoMdThumbsUp"


class IoMdThunderstorm(rx.Component):
    library = "react-icons/io"
    tag = "IoMdThunderstorm"


class IoMdTime(rx.Component):
    library = "react-icons/io"
    tag = "IoMdTime"


class IoMdTimer(rx.Component):
    library = "react-icons/io"
    tag = "IoMdTimer"


class IoMdToday(rx.Component):
    library = "react-icons/io"
    tag = "IoMdToday"


class IoMdTrain(rx.Component):
    library = "react-icons/io"
    tag = "IoMdTrain"


class IoMdTransgender(rx.Component):
    library = "react-icons/io"
    tag = "IoMdTransgender"


class IoMdTrash(rx.Component):
    library = "react-icons/io"
    tag = "IoMdTrash"


class IoMdTrendingDown(rx.Component):
    library = "react-icons/io"
    tag = "IoMdTrendingDown"


class IoMdTrendingUp(rx.Component):
    library = "react-icons/io"
    tag = "IoMdTrendingUp"


class IoMdTrophy(rx.Component):
    library = "react-icons/io"
    tag = "IoMdTrophy"


class IoMdTv(rx.Component):
    library = "react-icons/io"
    tag = "IoMdTv"


class IoMdUmbrella(rx.Component):
    library = "react-icons/io"
    tag = "IoMdUmbrella"


class IoMdUndo(rx.Component):
    library = "react-icons/io"
    tag = "IoMdUndo"


class IoMdUnlock(rx.Component):
    library = "react-icons/io"
    tag = "IoMdUnlock"


class IoMdVideocam(rx.Component):
    library = "react-icons/io"
    tag = "IoMdVideocam"


class IoMdVolumeHigh(rx.Component):
    library = "react-icons/io"
    tag = "IoMdVolumeHigh"


class IoMdVolumeLow(rx.Component):
    library = "react-icons/io"
    tag = "IoMdVolumeLow"


class IoMdVolumeMute(rx.Component):
    library = "react-icons/io"
    tag = "IoMdVolumeMute"


class IoMdVolumeOff(rx.Component):
    library = "react-icons/io"
    tag = "IoMdVolumeOff"


class IoMdWalk(rx.Component):
    library = "react-icons/io"
    tag = "IoMdWalk"


class IoMdWallet(rx.Component):
    library = "react-icons/io"
    tag = "IoMdWallet"


class IoMdWarning(rx.Component):
    library = "react-icons/io"
    tag = "IoMdWarning"


class IoMdWatch(rx.Component):
    library = "react-icons/io"
    tag = "IoMdWatch"


class IoMdWater(rx.Component):
    library = "react-icons/io"
    tag = "IoMdWater"


class IoMdWifi(rx.Component):
    library = "react-icons/io"
    tag = "IoMdWifi"


class IoMdWine(rx.Component):
    library = "react-icons/io"
    tag = "IoMdWine"


class IoMdWoman(rx.Component):
    library = "react-icons/io"
    tag = "IoMdWoman"


